Package: pandoc
Title: Manage and Run Universal Converter 'Pandoc' from 'R'
Version: 0.2.0
Authors@R: c(
    person("Christophe", "Dervieux", , "cderv@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4474-2498")),
    person(given = "Posit Software, PBC", role = c("cph", "fnd"))
  )
Description: Provides a set of tools to install, manage and run several
    'Pandoc' versions.
License: MIT + file LICENSE
URL: https://github.com/cderv/pandoc, https://cderv.github.io/pandoc/
BugReports: https://github.com/cderv/pandoc/issues
Depends: R (>= 3.5.0)
Imports: fs, rappdirs, rlang (>= 1.0.1)
Suggests: covr, gh, rmarkdown (>= 2.14), testthat (>= 3.0.0), tibble,
        withr
Config/Needs/website: tidyverse/tidytemplate, dplyr, tidyr, purrr
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-08-24 10:07:24 UTC; chris
Author: Christophe Dervieux [aut, cre]
    (<https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd]
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2023-08-24 11:00:08 UTC
Built: R 4.4.0; ; 2024-04-30 21:41:59 UTC; unix
