# Generated by roxygen2: do not edit by hand

S3method(print,pandoc_raw_result)
export(local_pandoc_version)
export(pandoc_activate)
export(pandoc_available)
export(pandoc_available_releases)
export(pandoc_bin)
export(pandoc_bin_browse)
export(pandoc_browse_citation)
export(pandoc_browse_exit_code)
export(pandoc_browse_extension)
export(pandoc_browse_manual)
export(pandoc_browse_option)
export(pandoc_browse_release)
export(pandoc_citeproc_bin)
export(pandoc_convert)
export(pandoc_export_data_file)
export(pandoc_export_highlight_theme)
export(pandoc_export_reference_doc)
export(pandoc_export_template)
export(pandoc_install)
export(pandoc_install_nightly)
export(pandoc_installed_latest)
export(pandoc_installed_versions)
export(pandoc_is_active)
export(pandoc_is_installed)
export(pandoc_list_abbreviations)
export(pandoc_list_extensions)
export(pandoc_list_formats)
export(pandoc_list_highlight_languages)
export(pandoc_list_highlight_style)
export(pandoc_locate)
export(pandoc_rstudio_bin)
export(pandoc_rstudio_version)
export(pandoc_run)
export(pandoc_system_bin)
export(pandoc_system_version)
export(pandoc_uninstall)
export(pandoc_update)
export(pandoc_version)
export(with_pandoc_version)
import(fs)
import(rlang)
importFrom(rappdirs,user_data_dir)
