# pandoc_list_formats

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["type", "formats"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input", "input"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["biblatex", "bibtex", "commonmark", "commonmark_x", "creole", "csljson", "csv", "docbook", "docx", "dokuwiki", "epub", "fb2", "gfm", "haddock", "html", "ipynb", "jats", "jira", "json", "latex", "man", "markdown", "markdown_github", "markdown_mmd", "markdown_phpextra", "markdown_strict", "mediawiki", "muse", "native", "odt", "opml", "org", "rst", "t2t", "textile", "tikiwiki", "twiki", "vimwiki"]
        }
      ]
    }

---

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["type", "formats"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output", "output"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["asciidoc", "asciidoctor", "beamer", "biblatex", "bibtex", "commonmark", "commonmark_x", "context", "csljson", "docbook", "docbook4", "docbook5", "docx", "dokuwiki", "dzslides", "epub", "epub2", "epub3", "fb2", "gfm", "haddock", "html", "html4", "html5", "icml", "ipynb", "jats", "jats_archiving", "jats_articleauthoring", "jats_publishing", "jira", "json", "latex", "man", "markdown", "markdown_github", "markdown_mmd", "markdown_phpextra", "markdown_strict", "mediawiki", "ms", "muse", "native", "odt", "opendocument", "opml", "org", "pdf", "plain", "pptx", "revealjs", "rst", "rtf", "s5", "slideous", "slidy", "tei", "texinfo", "textile", "xwiki", "zimwiki"]
        }
      ]
    }

# pandoc_list_extensions

    Code
      pandoc_list_extensions("markdown", version = "2.7.3")
    Condition
      Error in `pandoc_list_extensions()`:
      ! This feature is only available for Pandoc `2.8` and above.

---

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["format", "extensions", "default"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown", "markdown"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["abbreviations", "all_symbols_escapable", "angle_brackets_escapable", "ascii_identifiers", "auto_identifiers", "autolink_bare_uris", "backtick_code_blocks", "blank_before_blockquote", "blank_before_header", "bracketed_spans", "citations", "compact_definition_lists", "definition_lists", "east_asian_line_breaks", "emoji", "escaped_line_breaks", "example_lists", "fancy_lists", "fenced_code_attributes", "fenced_code_blocks", "fenced_divs", "footnotes", "four_space_rule", "gfm_auto_identifiers", "grid_tables", "hard_line_breaks", "header_attributes", "ignore_line_breaks", "implicit_figures", "implicit_header_references", "inline_code_attributes", "inline_notes", "intraword_underscores", "latex_macros", "line_blocks", "link_attributes", "lists_without_preceding_blankline", "literate_haskell", "markdown_attribute", "markdown_in_html_blocks", "mmd_header_identifiers", "mmd_link_attributes", "mmd_title_block", "multiline_tables", "native_divs", "native_spans", "old_dashes", "pandoc_title_block", "pipe_tables", "raw_attribute", "raw_html", "raw_tex", "shortcut_reference_links", "simple_tables", "smart", "space_in_atx_header", "spaced_reference_links", "startnum", "strikeout", "subscript", "superscript", "task_lists", "table_captions", "tex_math_dollars", "tex_math_double_backslash", "tex_math_single_backslash", "yaml_metadata_block", "gutenberg"]
        },
        {
          "type": "logical",
          "attributes": {},
          "value": [false, true, false, false, true, false, true, true, true, true, true, false, true, false, false, true, true, true, true, true, true, true, false, false, true, false, true, false, true, true, true, true, true, true, true, true, false, false, false, true, false, false, false, true, true, true, false, true, true, true, true, true, true, true, true, true, false, true, true, true, true, true, true, true, false, false, true, false]
        }
      ]
    }

---

    {
      "type": "list",
      "attributes": {
        "class": {
          "type": "character",
          "attributes": {},
          "value": ["tbl_df", "tbl", "data.frame"]
        },
        "row.names": {
          "type": "integer",
          "attributes": {},
          "value": [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26]
        },
        "names": {
          "type": "character",
          "attributes": {},
          "value": ["format", "extensions", "default"]
        }
      },
      "value": [
        {
          "type": "character",
          "attributes": {},
          "value": ["gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm", "gfm"]
        },
        {
          "type": "character",
          "attributes": {},
          "value": ["ascii_identifiers", "autolink_bare_uris", "bracketed_spans", "definition_lists", "east_asian_line_breaks", "emoji", "fancy_lists", "fenced_code_attributes", "fenced_divs", "footnotes", "gfm_auto_identifiers", "hard_line_breaks", "implicit_figures", "implicit_header_references", "pipe_tables", "raw_attribute", "raw_html", "raw_tex", "smart", "strikeout", "subscript", "superscript", "task_lists", "tex_math_dollars", "attributes", "sourcepos"]
        },
        {
          "type": "logical",
          "attributes": {},
          "value": [false, true, false, false, false, true, false, false, false, false, true, false, false, false, true, false, true, false, false, true, false, false, true, false, false, false]
        }
      ]
    }

# pandoc_list_highlight_style

    Code
      pandoc_list_highlight_style()
    Output
      [1] "pygments"   "tango"      "espresso"   "zenburn"    "kate"      
      [6] "monochrome" "breezedark" "haddock"   

# pandoc_list_highlight_languages

    Code
      pandoc_list_highlight_languages()
    Output
        [1] "abc"             "actionscript"    "ada"             "agda"           
        [5] "apache"          "asn1"            "asp"             "ats"            
        [9] "awk"             "bash"            "bibtex"          "boo"            
       [13] "c"               "changelog"       "clojure"         "cmake"          
       [17] "coffee"          "coldfusion"      "comments"        "commonlisp"     
       [21] "cpp"             "cs"              "css"             "curry"          
       [25] "d"               "default"         "diff"            "djangotemplate" 
       [29] "dockerfile"      "dot"             "doxygen"         "doxygenlua"     
       [33] "dtd"             "eiffel"          "elixir"          "elm"            
       [37] "email"           "erlang"          "fasm"            "fortranfixed"   
       [41] "fortranfree"     "fsharp"          "gcc"             "glsl"           
       [45] "gnuassembler"    "go"              "graphql"         "groovy"         
       [49] "hamlet"          "haskell"         "haxe"            "html"           
       [53] "idris"           "ini"             "isocpp"          "j"              
       [57] "java"            "javadoc"         "javascript"      "javascriptreact"
       [61] "json"            "jsp"             "julia"           "kotlin"         
       [65] "latex"           "lex"             "lilypond"        "literatecurry"  
       [69] "literatehaskell" "llvm"            "lua"             "m4"             
       [73] "makefile"        "mandoc"          "markdown"        "mathematica"    
       [77] "matlab"          "maxima"          "mediawiki"       "metafont"       
       [81] "mips"            "modelines"       "modula2"         "modula3"        
       [85] "monobasic"       "mustache"        "nasm"            "nim"            
       [89] "noweb"           "objectivec"      "objectivecpp"    "ocaml"          
       [93] "octave"          "opencl"          "pascal"          "perl"           
       [97] "php"             "pike"            "postscript"      "povray"         
      [101] "powershell"      "prolog"          "protobuf"        "pure"           
      [105] "purebasic"       "python"          "qml"             "r"              
      [109] "relaxng"         "relaxngcompact"  "rest"            "rhtml"          
      [113] "roff"            "ruby"            "rust"            "scala"          
      [117] "scheme"          "sci"             "sed"             "sgml"           
      [121] "sml"             "spdxcomments"    "sql"             "sqlmysql"       
      [125] "sqlpostgresql"   "stata"           "tcl"             "tcsh"           
      [129] "texinfo"         "toml"            "typescript"      "verilog"        
      [133] "vhdl"            "xml"             "xorg"            "xslt"           
      [137] "xul"             "yacc"            "yaml"            "zsh"            

# pandoc_list_abbreviations

    Code
      pandoc_list_abbreviations()
    Output
       [1] "aet."   "aetat." "al."    "Apr."   "Aug."   "bk."    "Bros."  "c."    
       [9] "Capt."  "cf."    "ch."    "chap."  "chs."   "Co."    "col."   "Corp." 
      [17] "cp."    "d."     "Dec."   "Dr."    "e.g."   "ed."    "eds."   "esp."  
      [25] "f."     "fasc."  "Feb."   "ff."    "fig."   "fl."    "fol."   "fols." 
      [33] "Fr."    "Gen."   "Gov."   "Hon."   "i.e."   "ill."   "Inc."   "incl." 
      [41] "Jan."   "Jr."    "Jul."   "Jun."   "Ltd."   "M.A."   "M.D."   "Mar."  
      [49] "Mr."    "Mrs."   "Ms."    "n."     "n.b."   "nn."    "No."    "Nov."  
      [57] "Oct."   "p."     "Ph.D."  "pp."    "Pres."  "Prof."  "pt."    "q.v."  
      [65] "Rep."   "Rev."   "s.v."   "s.vv."  "saec."  "sec."   "Sen."   "Sep."  
      [73] "Sept."  "Sgt."   "Sr."    "St."    "univ."  "viz."   "vol."   "vs."   

