# url_view

    Code
      url_view("https://example.org/")
    Message
      i Open URL
      https://example.org/

# pandoc_browse_release()

    Code
      pandoc_browse_release()
    Message
      i Open URL
      https://github.com/jgm/pandoc/releases/latest

---

    Code
      pandoc_browse_release("2.7.3")
    Message
      i Open URL
      https://github.com/jgm/pandoc/releases/2.7.3

# pandoc_browse_manual()

    Code
      pandoc_browse_manual()
    Message
      i Open URL
      https://pandoc.org/MANUAL.html

---

    Code
      pandoc_browse_manual("description")
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#description

# pandoc_browse_extension()

    Code
      pandoc_browse_extension("smart")
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#extension-smart

# pandoc_browse_citation()

    Code
      pandoc_browse_citation()
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#citations

# pandoc_browse_exit_code()

    Code
      pandoc_browse_exit_code()
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#exit-codes

# pandoc_browse_option()

    Code
      pandoc_browse_option()
    Message
      i Open URL
      https://pandoc.org/MANUAL.html##options

---

    Code
      pandoc_browse_option("quiet")
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#option--quiet

---

    Code
      pandoc_browse_option("--quiet")
    Message
      i Open URL
      https://pandoc.org/MANUAL.html#option--quiet

